# Changelog

## [0.3.0](https://github.com/mkrg01/phenoradar/compare/v0.2.0...v0.3.0) (2026-03-11)


### Features

* add feature-filter/sparsity artifacts and visualization ([a05b6ac](https://github.com/mkrg01/phenoradar/commit/a05b6ac937aa7023d0091fb4a026400d4c5593b4))
* add feature-filter/sparsity artifacts and visualization ([8e423c5](https://github.com/mkrg01/phenoradar/commit/8e423c52587cdbd92497cc62a639ab6dab864717))


### Documentation

* remove release automation documentation ([98029bb](https://github.com/mkrg01/phenoradar/commit/98029bb6c3bf2ed532dddadb9dadf947c667ee2c))

## [0.2.0](https://github.com/mkrg01/phenoradar/compare/v0.1.0...v0.2.0) (2026-03-10)


### Features

* add CV train/validation log-loss artifact and visualization ([f86083f](https://github.com/mkrg01/phenoradar/commit/f86083fd444b5831eb3c22f298726ffda5a9d05e))
* **figures:** add model selection trials panel visualization ([45f2929](https://github.com/mkrg01/phenoradar/commit/45f2929208b1a374608288fac920535487b2a73e))
* **figures:** add species-level CV/external probability plots ([281d99e](https://github.com/mkrg01/phenoradar/commit/281d99e9c5b804ae1ddcd561d9921f908d1512f4))
* make log_loss the default selection metric and add split-level loss diagnostics/figures ([e54a0f5](https://github.com/mkrg01/phenoradar/commit/e54a0f585f4e392ae16f3dabaf032ce9daf0509d))
* **model-selection:** add log_loss as selectable metric and make it the default ([ffc1524](https://github.com/mkrg01/phenoradar/commit/ffc15243e51da35ce26cdfd947abee057aa1fa90))
* **run:** add split-level loss artifacts and figures for final refit ([a9b9476](https://github.com/mkrg01/phenoradar/commit/a9b9476c834c0671ce5c6963b0f2512d3bd22333))


### Documentation

* add active-development warning callout ([32461e0](https://github.com/mkrg01/phenoradar/commit/32461e041d68e324e0edd4e7aebbd285e6787275))

## 0.1.0 (2026-02-28)


### Features

* PhenoRadar baseline ([0081f23](https://github.com/mkrg01/phenoradar/commit/0081f2384339810ec449288c5532dad5ad104338))


### Documentation

* update Python badge for supported versions ([c9f9417](https://github.com/mkrg01/phenoradar/commit/c9f9417516f4b840d029460828f000ea6977ccf8))
